@@ -218,7 +218,7 @@ static Graphic ImpGetScaledGraphic( const Graphic& rGraphic, FilterConfigItem& r
         // Resolution is set
         if( nMode == 1 )
         {
-            BitmapEx    aBitmap( rGraphic.GetBitmapEx() );
+            Bitmap      aBitmap( rGraphic.GetBitmap() );
             MapMode     aMap( MapUnit::Map100thInch );
 
             sal_Int32   nDPI = rConfigItem.ReadInt32( u"Resolution"_ustr, 75 );
@@ -246,9 +246,9 @@ static Graphic ImpGetScaledGraphic( const Graphic& rGraphic, FilterConfigItem& r
         sal_Int32 nColors = rConfigItem.ReadInt32( u"Color"_ustr, 0 );
         if ( nColors )  // graphic conversion necessary ?
         {
-            BitmapEx aBmpEx( aGraphic.GetBitmapEx() );
-            aBmpEx.Convert( static_cast<BmpConversion>(nColors) );   // the entries in the xml section have the same meaning as
-            aGraphic = aBmpEx;                          // they have in the BmpConversion enum, so it should be
+            Bitmap aBmp( aGraphic.GetBitmap() );
+            aBmp.Convert( static_cast<BmpConversion>(nColors) );   // the entries in the xml section have the same meaning as
+            aGraphic = aBmp;                          // they have in the BmpConversion enum, so it should be
         }                                               // allowed to cast them
     }
     else
@@ -443,8 +443,10 @@ ErrCode GraphicFilter::CanImportGraphic( std::u16string_view rMainUrl, SvStream&
 }
 
 //SJ: TODO, we need to create a GraphicImporter component
-ErrCode GraphicFilter::ImportGraphic( Graphic& rGraphic, const INetURLObject& rPath,
-                                     sal_uInt16 nFormat, sal_uInt16 * pDeterminedFormat, GraphicFilterImportFlags nImportFlags )
+ErrCode GraphicFilter::ImportGraphic(
+    Graphic& rGraphic, const INetURLObject& rPath, sal_uInt16 nFormat,
+    sal_uInt16 * pDeterminedFormat, GraphicFilterImportFlags nImportFlags,
+    const css::uno::Reference<css::task::XInteractionHandler>& xInteractionHandler)
 {
     SAL_WARN_IF( rPath.GetProtocol() == INetProtocol::NotValid, "vcl.filter", "GraphicFilter::ImportGraphic() : ProtType == INetProtocol::NotValid" );
 
@@ -459,7 +461,7 @@ ErrCode GraphicFilter::ImportGraphic( Graphic& rGraphic, const INetURLObject& rP
     std::unique_ptr<SvStream> xStream(::utl::UcbStreamHelper::CreateStream( aMainUrl, StreamMode::READ | StreamMode::SHARE_DENYNONE ));
     if (xStream)
     {
-        nRetValue = ImportGraphic( rGraphic, aMainUrl, *xStream, nFormat, pDeterminedFormat, nImportFlags );
+        nRetValue = ImportGraphic(rGraphic, aMainUrl, *xStream, nFormat, pDeterminedFormat, nImportFlags, -1, xInteractionHandler);
     }
     return nRetValue;
 }
@@ -476,9 +478,6 @@ struct GraphicImportContext
     std::shared_ptr<ImportOutput> m_pImportOutput;
     /// Write pixel data using this access.
     std::unique_ptr<BitmapScopedWriteAccess> m_pAccess;
-    std::unique_ptr<BitmapScopedWriteAccess> m_pAlphaAccess;
-    // Need to have an AlphaMask instance to keep its lifetime.
-    AlphaMask mAlphaMask;
     /// Signals if import finished correctly.
     ErrCode m_nStatus = ERRCODE_GRFILTER_FILTERERROR;
     /// Original graphic format.
@@ -524,7 +523,7 @@ void GraphicImportTask::doImport(GraphicImportContext& rContext)
     {
         vcl::ImportPNG(*rContext.m_pStream, *rContext.m_pImportOutput,
                 rContext.m_nImportFlags | GraphicFilterImportFlags::UseExistingBitmap,
-                rContext.m_pAccess.get(), rContext.m_pAlphaAccess.get());
+                rContext.m_pAccess.get());
 
         if (!rContext.m_pImportOutput->moBitmap || rContext.m_pImportOutput->moBitmap->IsEmpty())
         {
@@ -533,7 +532,7 @@ void GraphicImportTask::doImport(GraphicImportContext& rContext)
     }
 }
 
-void GraphicFilter::ImportGraphics(std::vector< std::shared_ptr<Graphic> >& rGraphics, std::vector< std::unique_ptr<SvStream> > vStreams)
+std::vector<Graphic> GraphicFilter::ImportGraphics(std::vector<std::unique_ptr<SvStream>> vStreams)
 {
     static bool bThreads = !getenv("VCL_NO_THREAD_IMPORT");
     std::vector<GraphicImportContext> aContexts;
@@ -571,7 +570,7 @@ void GraphicFilter::ImportGraphics(std::vector< std::shared_ptr<Graphic> >& rGra
 
                     if (ImportJPEG( *rContext.m_pStream, *rContext.m_pImportOutput, rContext.m_nImportFlags | GraphicFilterImportFlags::OnlyCreateBitmap, nullptr))
                     {
-                        Bitmap& rBitmap = const_cast<Bitmap&>(rContext.m_pImportOutput->moBitmap->GetBitmap());
+                        Bitmap& rBitmap = *rContext.m_pImportOutput->moBitmap;
                         rContext.m_pAccess = std::make_unique<BitmapScopedWriteAccess>(rBitmap);
                         rContext.m_pStream->Seek(rContext.m_nStreamBegin);
                         if (bThreads)
@@ -585,23 +584,10 @@ void GraphicFilter::ImportGraphics(std::vector< std::shared_ptr<Graphic> >& rGra
                 else if (aFilterName.equalsIgnoreAsciiCase(IMP_PNG))
                 {
                     rContext.m_eLinkType = GfxLinkType::NativePng;
-                    if (vcl::ImportPNG( *rContext.m_pStream, *rContext.m_pImportOutput, rContext.m_nImportFlags | GraphicFilterImportFlags::OnlyCreateBitmap, nullptr, nullptr))
+                    if (vcl::ImportPNG( *rContext.m_pStream, *rContext.m_pImportOutput, rContext.m_nImportFlags | GraphicFilterImportFlags::OnlyCreateBitmap, nullptr))
                     {
-                        const BitmapEx& rBitmapEx = *rContext.m_pImportOutput->moBitmap;
-                        Bitmap& rBitmap = const_cast<Bitmap&>(rBitmapEx.GetBitmap());
+                        Bitmap& rBitmap = *rContext.m_pImportOutput->moBitmap;
                         rContext.m_pAccess = std::make_unique<BitmapScopedWriteAccess>(rBitmap);
-                        if(rBitmapEx.IsAlpha())
-                        {
-                            // The separate alpha bitmap causes a number of complications. Not only
-                            // we need to have an extra bitmap access for it, but we also need
-                            // to keep an AlphaMask instance in the context. This is because
-                            // BitmapEx internally keeps Bitmap and not AlphaMask (because the Bitmap
-                            // may be also a mask, not alpha). So BitmapEx::GetAlpha() returns
-                            // a temporary, and direct access to the Bitmap wouldn't work
-                            // with AlphaScopedBitmapAccess. *sigh*
-                            rContext.mAlphaMask = rBitmapEx.GetAlphaMask();
-                            rContext.m_pAlphaAccess = std::make_unique<BitmapScopedWriteAccess>(rContext.mAlphaMask);
-                        }
                         rContext.m_pStream->Seek(rContext.m_nStreamBegin);
                         if (bThreads)
                             rSharedPool.pushTask(std::make_unique<GraphicImportTask>(pTag, rContext));
@@ -620,22 +606,16 @@ void GraphicFilter::ImportGraphics(std::vector< std::shared_ptr<Graphic> >& rGra
     rSharedPool.waitUntilDone(pTag);
 
     // Process data after import.
+    std::vector<Graphic> aGraphics;
+    aGraphics.reserve(aContexts.size());
     for (auto& rContext : aContexts)
     {
         rContext.m_pAccess.reset();
-        rContext.m_pAlphaAccess.reset();
-        if (!rContext.mAlphaMask.IsEmpty()) // Need to move the AlphaMask back to the BitmapEx.
-        {
-            BitmapEx aBitmapEx(rContext.m_pImportOutput->moBitmap->GetBitmap(), rContext.mAlphaMask);
-            rContext.m_pImportOutput->moBitmap = aBitmapEx;
-        }
-
-        std::shared_ptr<Graphic> pGraphic;
 
         if (rContext.m_nStatus == ERRCODE_NONE && rContext.m_pImportOutput && rContext.m_pImportOutput->moBitmap)
-            pGraphic = std::make_shared<Graphic>(*rContext.m_pImportOutput->moBitmap);
+            aGraphics.emplace_back(*rContext.m_pImportOutput->moBitmap);
         else
-            pGraphic = std::make_shared<Graphic>();
+            aGraphics.emplace_back();
 
         if (rContext.m_nStatus == ERRCODE_NONE && rContext.m_eLinkType != GfxLinkType::NONE)
         {
@@ -658,11 +638,10 @@ void GraphicFilter::ImportGraphics(std::vector< std::shared_ptr<Graphic> >& rGra
             }
 
             if (rContext.m_nStatus == ERRCODE_NONE)
-                pGraphic->SetGfxLink(std::make_shared<GfxLink>(aGraphicContent, rContext.m_eLinkType));
+                aGraphics.back().SetGfxLink(std::make_shared<GfxLink>(aGraphicContent, rContext.m_eLinkType));
         }
-
-        rGraphics.push_back(pGraphic);
     }
+    return aGraphics;
 }
 
 void GraphicFilter::MakeGraphicsAvailableThreaded(std::vector<Graphic*>& graphics)
@@ -691,17 +670,13 @@ void GraphicFilter::MakeGraphicsAvailableThreaded(std::vector<Graphic*>& graphic
     streams.reserve(toLoad.size());
     for( auto graphic : toLoad )
     {
-        streams.push_back( std::make_unique<SvMemoryStream>( const_cast<sal_uInt8*>(graphic->GetSharedGfxLink()->GetData()),
-            graphic->GetSharedGfxLink()->GetDataSize(), StreamMode::READ | StreamMode::WRITE));
+        streams.push_back(graphic->GetSharedGfxLink()->getDataContainer().getAsStream());
     }
-    std::vector< std::shared_ptr<Graphic>> loadedGraphics;
-    loadedGraphics.reserve(streams.size());
-    ImportGraphics(loadedGraphics, std::move(streams));
+    std::vector<Graphic> loadedGraphics = ImportGraphics(std::move(streams));
     assert(loadedGraphics.size() == toLoad.size());
     for( size_t i = 0; i < toLoad.size(); ++i )
     {
-        if(loadedGraphics[ i ] != nullptr)
-            toLoad[ i ]->ImplGetImpGraphic()->updateFromLoadedGraphic(loadedGraphics[ i ]->ImplGetImpGraphic());
+        toLoad[ i ]->ImplGetImpGraphic()->updateFromLoadedGraphic(loadedGraphics[ i ].ImplGetImpGraphic());
     }
 }
 
@@ -878,7 +853,7 @@ Graphic GraphicFilter::ImportUnloadedGraphic(SvStream& rIStream, sal_uInt64 size
 
             if (eLinkType == GfxLinkType::NativeGif && !aBinaryDataContainer.isEmpty())
             {
-                std::shared_ptr<SvStream> pMemoryStream = aBinaryDataContainer.getAsStream();
+                std::unique_ptr<SvStream> pMemoryStream = aBinaryDataContainer.getAsStream();
                 bAnimated = IsGIFAnimated(*pMemoryStream, aLogicSize);
                 if (!pSizeHint && aLogicSize.getWidth() && aLogicSize.getHeight())
                 {
@@ -928,7 +903,7 @@ ErrCode GraphicFilter::readPNG(SvStream & rStream, Graphic& rGraphic, GfxLinkTyp
     if (auto aMSGifChunk = vcl::PngImageReader::getMicrosoftGifChunk(rStream);
         !aMSGifChunk.isEmpty())
     {
-        std::shared_ptr<SvStream> pIStrm(aMSGifChunk.getAsStream());
+        std::unique_ptr<SvStream> pIStrm(aMSGifChunk.getAsStream());
 
         if (ImportGIF(*pIStrm, aImportOutput))
         {
@@ -959,8 +934,6 @@ ErrCode GraphicFilter::readPNG(SvStream & rStream, Graphic& rGraphic, GfxLinkTyp
 
 ErrCode GraphicFilter::readJPEG(SvStream & rStream, Graphic & rGraphic, GfxLinkType & rLinkType, GraphicFilterImportFlags nImportFlags)
 {
-    ErrCode aReturnCode = ERRCODE_NONE;
-
     // set LOGSIZE flag always, if not explicitly disabled
     // (see #90508 and #106763)
     if (!(nImportFlags & GraphicFilterImportFlags::DontSetLogsizeForJpeg))
@@ -968,36 +941,16 @@ ErrCode GraphicFilter::readJPEG(SvStream & rStream, Graphic & rGraphic, GfxLinkT
         nImportFlags |= GraphicFilterImportFlags::SetLogsizeForJpeg;
     }
 
-    sal_uInt64 nPosition = rStream.Tell();
     ImportOutput aImportOutput;
-    if (!ImportJPEG(rStream, aImportOutput, nImportFlags | GraphicFilterImportFlags::OnlyCreateBitmap, nullptr))
+    if (!ImportJPEG(rStream, aImportOutput, nImportFlags, nullptr))
     {
-        aReturnCode = ERRCODE_GRFILTER_FILTERERROR;
-    }
-    else
-    {
-        Bitmap& rBitmap = const_cast<Bitmap&>(aImportOutput.moBitmap->GetBitmap());
-        BitmapScopedWriteAccess pWriteAccess(rBitmap);
-        rStream.Seek(nPosition);
-        if (!ImportJPEG(rStream, aImportOutput, nImportFlags | GraphicFilterImportFlags::UseExistingBitmap, &pWriteAccess))
-        {
-            aReturnCode = ERRCODE_GRFILTER_FILTERERROR;
-        }
-        else
-        {
-            if (aImportOutput.moBitmap)
-            {
-                rGraphic = Graphic(*aImportOutput.moBitmap);
-                rLinkType = GfxLinkType::NativeJpg;
-            }
-            else
-            {
-                aReturnCode = ERRCODE_GRFILTER_FILTERERROR;
-            }
-        }
+        return ERRCODE_GRFILTER_FILTERERROR;
     }
 
-    return aReturnCode;
+    rGraphic = Graphic(*aImportOutput.moBitmap);
+    rLinkType = GfxLinkType::NativeJpg;
+
+    return ERRCODE_NONE;
 }
 
 ErrCode GraphicFilter::readSVG(SvStream & rStream, Graphic & rGraphic, GfxLinkType & rLinkType, BinaryDataContainer& rpGraphicContent)
@@ -1133,12 +1086,29 @@ ErrCode GraphicFilter::readEMF(SvStream & rStream, Graphic & rGraphic, GfxLinkTy
     return readWMF_EMF(rStream, rGraphic, rLinkType, VectorGraphicDataType::Emf);
 }
 
-ErrCode GraphicFilter::readPDF(SvStream& rStream, Graphic& rGraphic, GfxLinkType& rLinkType,
-                               sal_Int32 nPageIndex)
+ErrCode GraphicFilter::readPDF(
+   SvStream& rStream, Graphic& rGraphic, GfxLinkType& rLinkType, sal_Int32 nPageIndex,
+   const css::uno::Reference<css::task::XInteractionHandler>& xInteractionHandler,
+                               BinaryDataContainer& rpGraphicContent)
 {
-    if (vcl::ImportPDF(rStream, rGraphic, nPageIndex))
+    bool bEncrypted;
+    if (vcl::ImportPDF(rStream, rGraphic, nPageIndex, xInteractionHandler, bEncrypted))
     {
+        // ImportPDF put a modified version of the PDF in the Graphic, but
+        // by default we stash the original in the Link
         rLinkType = GfxLinkType::NativePdf;
+        if (bEncrypted)
+        {
+            // However, when we load an encrypted PDF, we want the modified PDF
+            // to stash into the Link as well, so that when the user opens a odg etc
+            // they don't need to enter multiple PDF passwords
+            auto const &rVectorGraphicDataPtr(rGraphic.getVectorGraphicData());
+            if (rVectorGraphicDataPtr &&
+                    !rVectorGraphicDataPtr->getBinaryDataContainer().isEmpty())
+            {
+                rpGraphicContent = rVectorGraphicDataPtr->getBinaryDataContainer();
+            }
+        }
         return ERRCODE_NONE;
     }
     else
@@ -1317,7 +1287,8 @@ ErrCode GraphicFilter::readWEBP(SvStream & rStream, Graphic & rGraphic, GfxLinkT
 ErrCode GraphicFilter::ImportGraphic(Graphic& rGraphic, std::u16string_view rPath,
                                      SvStream& rIStream, sal_uInt16 nFormat,
                                      sal_uInt16* pDeterminedFormat,
-                                     GraphicFilterImportFlags nImportFlags, sal_Int32 nPageIndex)
+                                     GraphicFilterImportFlags nImportFlags, sal_Int32 nPageIndex,
+                                     const css::uno::Reference<css::task::XInteractionHandler>& xInteractionHandler)
 {
     OUString aFilterName;
     sal_uInt64 nStreamBegin;
@@ -1361,106 +1332,104 @@ ErrCode GraphicFilter::ImportGraphic(Graphic& rGraphic, std::u16string_view rPat
     }
 
     // read graphic
+    if (aFilterName.equalsIgnoreAsciiCase(IMP_GIF))
     {
-        if (aFilterName.equalsIgnoreAsciiCase(IMP_GIF))
-        {
-            nStatus = readGIF(rIStream, rGraphic, eLinkType);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_PNG))
-        {
-            nStatus = readPNG(rIStream, rGraphic, eLinkType, aGraphicContent);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_JPEG))
-        {
-            nStatus = readJPEG(rIStream, rGraphic, eLinkType, nImportFlags);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_SVG) || aFilterName.equalsIgnoreAsciiCase(IMP_SVGZ))
-        {
-            nStatus = readSVG(rIStream, rGraphic, eLinkType, aGraphicContent);
-        }
-        else if( aFilterName.equalsIgnoreAsciiCase( IMP_XBM ) )
-        {
-            nStatus = readXBM(rIStream, rGraphic);
-        }
-        else if( aFilterName.equalsIgnoreAsciiCase( IMP_XPM ) )
-        {
-            nStatus = readXPM(rIStream, rGraphic);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_BMP))
-        {
-            nStatus = readBMP(rIStream, rGraphic, eLinkType);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_SVMETAFILE))
-        {
-            nStatus = readWithTypeSerializer(rIStream, rGraphic, eLinkType, aFilterName);
-        }
-        else if( aFilterName.equalsIgnoreAsciiCase(IMP_MOV))
-        {
-            nStatus = readWithTypeSerializer(rIStream, rGraphic, eLinkType, aFilterName);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_WMF) || aFilterName.equalsIgnoreAsciiCase(IMP_WMZ))
-        {
-            nStatus = readWMF(rIStream, rGraphic, eLinkType);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_EMF) || aFilterName.equalsIgnoreAsciiCase(IMP_EMZ))
-        {
-            nStatus = readEMF(rIStream, rGraphic, eLinkType);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_PDF))
-        {
-            nStatus = readPDF(rIStream, rGraphic, eLinkType, nPageIndex);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_TIFF) )
-        {
-            nStatus = readTIFF(rIStream, rGraphic, eLinkType);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_TGA) )
-        {
-            nStatus = readTGA(rIStream, rGraphic);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_PICT))
-        {
-            nStatus = readPICT(rIStream, rGraphic, eLinkType);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_MET))
-        {
-            nStatus = readMET(rIStream, rGraphic, eLinkType);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_RAS))
-        {
-            nStatus = readRAS(rIStream, rGraphic);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_PCX))
-        {
-            nStatus = readPCX(rIStream, rGraphic);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_EPS))
-        {
-            nStatus = readEPS(rIStream, rGraphic);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_PSD))
-        {
-            nStatus = readPSD(rIStream, rGraphic);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_PCD))
-        {
-            nStatus = readPCD(rIStream, rGraphic);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_PBM))
-        {
-            nStatus = readPBM(rIStream, rGraphic);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_DXF))
-        {
-            nStatus = readDXF(rIStream, rGraphic);
-        }
-        else if (aFilterName.equalsIgnoreAsciiCase(IMP_WEBP))
-        {
-            nStatus = readWEBP(rIStream, rGraphic, eLinkType);
-        }
-        else
-            nStatus = ERRCODE_GRFILTER_FILTERERROR;
+        nStatus = readGIF(rIStream, rGraphic, eLinkType);
     }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_PNG))
+    {
+        nStatus = readPNG(rIStream, rGraphic, eLinkType, aGraphicContent);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_JPEG))
+    {
+        nStatus = readJPEG(rIStream, rGraphic, eLinkType, nImportFlags);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_SVG) || aFilterName.equalsIgnoreAsciiCase(IMP_SVGZ))
+    {
+        nStatus = readSVG(rIStream, rGraphic, eLinkType, aGraphicContent);
+    }
+    else if( aFilterName.equalsIgnoreAsciiCase( IMP_XBM ) )
+    {
+        nStatus = readXBM(rIStream, rGraphic);
+    }
+    else if( aFilterName.equalsIgnoreAsciiCase( IMP_XPM ) )
+    {
+        nStatus = readXPM(rIStream, rGraphic);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_BMP))
+    {
+        nStatus = readBMP(rIStream, rGraphic, eLinkType);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_SVMETAFILE))
+    {
+        nStatus = readWithTypeSerializer(rIStream, rGraphic, eLinkType, aFilterName);
+    }
+    else if( aFilterName.equalsIgnoreAsciiCase(IMP_MOV))
+    {
+        nStatus = readWithTypeSerializer(rIStream, rGraphic, eLinkType, aFilterName);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_WMF) || aFilterName.equalsIgnoreAsciiCase(IMP_WMZ))
+    {
+        nStatus = readWMF(rIStream, rGraphic, eLinkType);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_EMF) || aFilterName.equalsIgnoreAsciiCase(IMP_EMZ))
+    {
+        nStatus = readEMF(rIStream, rGraphic, eLinkType);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_PDF))
+    {
+        nStatus = readPDF(rIStream, rGraphic, eLinkType, nPageIndex, xInteractionHandler, aGraphicContent);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_TIFF) )
+    {
+        nStatus = readTIFF(rIStream, rGraphic, eLinkType);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_TGA) )
+    {
+        nStatus = readTGA(rIStream, rGraphic);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_PICT))
+    {
+        nStatus = readPICT(rIStream, rGraphic, eLinkType);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_MET))
+    {
+        nStatus = readMET(rIStream, rGraphic, eLinkType);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_RAS))
+    {
+        nStatus = readRAS(rIStream, rGraphic);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_PCX))
+    {
+        nStatus = readPCX(rIStream, rGraphic);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_EPS))
+    {
+        nStatus = readEPS(rIStream, rGraphic);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_PSD))
+    {
+        nStatus = readPSD(rIStream, rGraphic);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_PCD))
+    {
+        nStatus = readPCD(rIStream, rGraphic);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_PBM))
+    {
+        nStatus = readPBM(rIStream, rGraphic);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_DXF))
+    {
+        nStatus = readDXF(rIStream, rGraphic);
+    }
+    else if (aFilterName.equalsIgnoreAsciiCase(IMP_WEBP))
+    {
+        nStatus = readWEBP(rIStream, rGraphic, eLinkType);
+    }
+    else
+        nStatus = ERRCODE_GRFILTER_FILTERERROR;
 
     if (nStatus == ERRCODE_NONE && eLinkType != GfxLinkType::NONE && !bLinkSet)
     {
@@ -1553,6 +1522,7 @@ ErrCode GraphicFilter::ExportGraphic( const Graphic& rGraphic, std::u16string_vi
     Graphic     aGraphic = ImpGetScaledGraphic( rGraphic, aConfigItem );
     eType = aGraphic.GetType();
 
+    SAL_INFO("vcl.filter", "GraphicFilter::ExportGraphic() Filter: " << aFilterName);
     if( pConfig->IsExportPixelFormat( nFormat ) )
     {
         if( eType != GraphicType::Bitmap )
@@ -1584,7 +1554,7 @@ ErrCode GraphicFilter::ExportGraphic( const Graphic& rGraphic, std::u16string_vi
             Graphic aGraphic2=aGraphic;
             aGraphic2.Draw(*aVirDev, Point(0, 0), aSizePixel); // this changes the MapMode
             aVirDev->SetMapMode(MapMode(MapUnit::MapPixel));
-            aGraphic=Graphic(aVirDev->GetBitmapEx(Point(0,0),aSizePixel));
+            aGraphic=Graphic(aVirDev->GetBitmap(Point(0,0),aSizePixel));
         }
     }
     if( rOStm.GetError() )
@@ -1731,11 +1701,11 @@ ErrCode GraphicFilter::ExportGraphic( const Graphic& rGraphic, std::u16string_vi
             }
             else if ( aFilterName.equalsIgnoreAsciiCase( EXP_PNG ) )
             {
-                auto aBitmapEx = aGraphic.GetBitmapEx();
+                auto aBitmap = aGraphic.GetBitmap();
                 vcl::PngImageWriter aPNGWriter( rOStm );
                 if ( pFilterData )
                     aPNGWriter.setParameters( *pFilterData );
-                aPNGWriter.write( aBitmapEx );
+                aPNGWriter.write( aBitmap );
 
                 if( rOStm.GetError() )
                     nStatus = ERRCODE_GRFILTER_IOERROR;
@@ -1938,9 +1908,10 @@ GraphicFilter& GraphicFilter::GetGraphicFilter()
     return gStandardFilter.m_aFilter;
 }
 
-ErrCode GraphicFilter::LoadGraphic( const OUString &rPath, const OUString &rFilterName,
+ErrCode GraphicFilter::LoadGraphic(const OUString &rPath, const OUString &rFilterName,
                  Graphic& rGraphic, GraphicFilter* pFilter,
-                 sal_uInt16* pDeterminedFormat )
+                 sal_uInt16* pDeterminedFormat,
+                 const css::uno::Reference<css::task::XInteractionHandler>& xInteractionHandler)
 {
     if ( !pFilter )
         pFilter = &GetGraphicFilter();
@@ -1962,9 +1933,9 @@ ErrCode GraphicFilter::LoadGraphic( const OUString &rPath, const OUString &rFilt
 
     ErrCode nRes = ERRCODE_NONE;
     if ( !pStream )
-        nRes = pFilter->ImportGraphic( rGraphic, aURL, nFilter, pDeterminedFormat );
+        nRes = pFilter->ImportGraphic(rGraphic, aURL, nFilter, pDeterminedFormat, GraphicFilterImportFlags::NONE, xInteractionHandler);
     else
-        nRes = pFilter->ImportGraphic( rGraphic, rPath, *pStream, nFilter, pDeterminedFormat );
+        nRes = pFilter->ImportGraphic(rGraphic, rPath, *pStream, nFilter, pDeterminedFormat, GraphicFilterImportFlags::NONE, -1, xInteractionHandler);
 
 #ifdef DBG_UTIL
     OUString aReturnString;
